<?php

/**
 * WebAdmin Language File
* 中文(zh-CN)
*
* Please Note: These language files will be overwritten during software updates.
*
* @author     LiteSpeed Technoglogies
* @copyright  Copyright (c) LiteSpeed 2014-2020
* @link       https://www.litespeedtech.com/
*/

global $_gmsg;

$_gmsg['menu_cloudimage'] = '云镜像';
$_gmsg['menu_cluster'] = '集群';
$_gmsg['menu_community'] = '社区';
$_gmsg['menu_compilephp'] = '编译 PHP';
$_gmsg['menu_dashboard'] = '主面板';
$_gmsg['menu_devgroup'] = '开发者邮件列表';
$_gmsg['menu_docs'] = '文档';
$_gmsg['menu_forum'] = '论坛';
$_gmsg['menu_general'] = '常规';
$_gmsg['menu_guides'] = '配置指南';
$_gmsg['menu_help'] = '帮助';
$_gmsg['menu_home'] = '首页';
$_gmsg['menu_logviewer'] = '查看服务器日志';
$_gmsg['menu_releaselog'] = '发布日志';
$_gmsg['menu_restart'] = '平滑重启';
$_gmsg['menu_rtstats'] = '实时统计';
$_gmsg['menu_serv'] = '服务器';
$_gmsg['menu_sl'] = '监听器';
$_gmsg['menu_sl_'] = '监听器';
$_gmsg['menu_slack'] = 'Slack';
$_gmsg['menu_toggledebug'] = '调试日志开关';
$_gmsg['menu_tools'] = '工具';
$_gmsg['menu_tp'] = '虚拟主机模板';
$_gmsg['menu_tp_'] = '虚拟主机模板';
$_gmsg['menu_versionmgr'] = '版本管理';
$_gmsg['menu_vh'] = '虚拟主机';
$_gmsg['menu_vh_'] = '虚拟主机';
$_gmsg['menu_webadmin'] = '管理控制台设置';


$_gmsg['tab_addons'] = '附加功能';
$_gmsg['tab_base'] = '基本';
$_gmsg['tab_cache'] = '缓存';
$_gmsg['tab_ctx'] = '资源集';
$_gmsg['tab_ext'] = '外部应用程序';
$_gmsg['tab_g'] = '常规';
$_gmsg['tab_log'] = '日志';
$_gmsg['tab_mod'] = '模块';
$_gmsg['tab_rails'] = '应用服务器';
$_gmsg['tab_requestfilter'] = '请求过滤';
$_gmsg['tab_rewrite'] = '重写';
$_gmsg['tab_sec'] = '安全';
$_gmsg['tab_sh'] = '脚本处理器';
$_gmsg['tab_ssl'] = 'SSL';
$_gmsg['tab_top'] = '摘要';
$_gmsg['tab_tp'] = '模板';
$_gmsg['tab_tuning'] = '调节';
$_gmsg['tab_user'] = '用户';
$_gmsg['tab_wsp'] = '网络套接字代理';


$_gmsg['btn_add'] = '添加';
$_gmsg['btn_back'] = '返回';
$_gmsg['btn_cancel'] = '取消';
$_gmsg['btn_delete'] = '删除';
$_gmsg['btn_edit'] = '编辑';
$_gmsg['btn_go'] = '继续';
$_gmsg['btn_instantiate'] = '实例化';
$_gmsg['btn_next'] = '下一步';
$_gmsg['btn_prev'] = '上一步';
$_gmsg['btn_refresh'] = '刷新';
$_gmsg['btn_save'] = '保存';
$_gmsg['btn_signin'] = '登录';
$_gmsg['btn_view'] = '查看';
$_gmsg['btn_yes'] = '是';


$_gmsg['note_collapsemenu'] = '收起菜单';
$_gmsg['note_configmodified'] = '配置已修改。要使修改生效，请进行平滑重启。';
$_gmsg['note_confirm_delete'] = '你确定要删除这个条目吗？这将从配置文件中被永久移除。';
$_gmsg['note_confirm_instantiate'] = '你确定你想要实例化这个虚拟主机吗？这将为该虚拟主机创建一个独立的配置文件。';
$_gmsg['note_copyrightreserved'] = '保留所有权利。';
$_gmsg['note_curbranch'] = '当前分支';
$_gmsg['note_curver'] = '当前版本';
$_gmsg['note_dataretrievedat'] = '数据接收于';
$_gmsg['note_entfeature'] = '这个特性仅适用于企业版';
$_gmsg['note_example'] = '范例';
$_gmsg['note_fullscreen'] = '全屏模式';
$_gmsg['note_inputerr'] = '检查到输入错误，请改正后继续。';
$_gmsg['note_loadavg'] = '系统平均负载(Load)';
$_gmsg['note_logout'] = '为进一步提高安全性，注销后请关闭浏览器窗口。';
$_gmsg['note_multicpufeature'] = '这个特性仅适用于多CPU版';
$_gmsg['note_newver'] = '新版本';
$_gmsg['note_number'] = '数值';
$_gmsg['note_numvalidrange'] = '数值有效范围';
$_gmsg['note_readonly_mode'] = '在配置文件中检测到包含文件,进入只读模式.';
$_gmsg['note_select_option'] = '请选择';
$_gmsg['note_serv_level'] = '服务器级';
$_gmsg['note_signout'] = '注销';
$_gmsg['note_syntax'] = '语法';
$_gmsg['note_tips'] = '提示';
$_gmsg['note_vh_level'] = '虚拟主机级';


$_gmsg['err_faildetectdlmethod'] = '无法检测下载方式(请安装curl、fetch或wget)';
$_gmsg['err_failreadfile'] = '读取文件失败';
$_gmsg['err_illegalcharfound'] = '值中包含非法字符';
$_gmsg['err_invalidpath'] = '无效路径';
$_gmsg['err_invalidvalat'] = '以下值是无效的';
$_gmsg['err_loggedoff'] = '你已经注销。';
$_gmsg['err_login'] = '身份认证失败。';
$_gmsg['err_parentdirnotexist'] = '父目录不存在';
$_gmsg['err_requireabspath'] = '要求绝对路径';
$_gmsg['err_sessiontimeout'] = '你的会话已超时。';
$_gmsg['err_valcannotempty'] = '值不能为空';


$_gmsg['l_accessallow'] = '允许列表';
$_gmsg['l_accessallowed'] = '允许的访问';
$_gmsg['l_accesscontrol'] = '访问控制';
$_gmsg['l_accessdenied'] = '拒绝的访问';
$_gmsg['l_accessdeny'] = '拒绝列表';
$_gmsg['l_accessdenydir'] = '拒绝访问的目录';
$_gmsg['l_accessfilename'] = '访问文件名称';
$_gmsg['l_accesslog'] = '访问日志';
$_gmsg['l_action'] = '动作';
$_gmsg['l_adddefaultcharset'] = '添加默认字符集';
$_gmsg['l_address'] = '地址';
$_gmsg['l_addresssettings'] = '地址设置';
$_gmsg['l_adminemails'] = '管理员邮箱';
$_gmsg['l_adminlistenersettings'] = '管理界面监听器地址设置';
$_gmsg['l_adminuser'] = '网络管理员用户';
$_gmsg['l_adminusers'] = '网络管理员用户';
$_gmsg['l_aioblocksize'] = 'AIO 块大小';
$_gmsg['l_allowbrowse'] = '可访问';
$_gmsg['l_allowdirectaccess'] = '允许直接访问';
$_gmsg['l_allowedRobotHits'] = '允许的机器人命中';
$_gmsg['l_allowedhosts'] = '允许的域名';
$_gmsg['l_allowoverride'] = '允许覆盖';
$_gmsg['l_allowsetuid'] = '允许设置UID';
$_gmsg['l_allowsymbollink'] = '跟随符号链接';
$_gmsg['l_apachebinpath'] = 'Apache执行程序路径';
$_gmsg['l_apacheconf'] = 'Apache Style设置';
$_gmsg['l_apacheconffile'] = 'Apache配置文件';
$_gmsg['l_apacheenablefp'] = '启用FrontPage扩展';
$_gmsg['l_apacheenvvars'] = 'Apache环境变量';
$_gmsg['l_apachehandledcontent'] = 'Apache处理的内容';
$_gmsg['l_apacheignoredmodules'] = '忽略的Apache模块';
$_gmsg['l_apacheipoffset'] = 'Apache监听IP偏移';
$_gmsg['l_apacheportoffset'] = 'Apache监听端口偏移';
$_gmsg['l_apachestyleconf'] = 'Apache样式设置';
$_gmsg['l_apptype'] = 'Application Type';
$_gmsg['l_authname'] = '认证名称';
$_gmsg['l_authorizer'] = '认证器';
$_gmsg['l_authrealm'] = '认证领域';
$_gmsg['l_autoLoadRewriteHtaccess'] = '自动加载 .htaccess';
$_gmsg['l_autofix503'] = '自动修复503错误';
$_gmsg['l_autoindex'] = '自动索引';
$_gmsg['l_autoindexuri'] = '自动索引URI';
$_gmsg['l_autoreloadapacheconf'] = '变动时自动重载';
$_gmsg['l_autostart'] = '自动启动';
$_gmsg['l_autoupdatedownload'] = '下载更新';
$_gmsg['l_autoupdateinterval'] = '检查更新';
$_gmsg['l_awstatesintegration'] = 'AWStats整合';
$_gmsg['l_awstatsuri'] = 'AWStats URI';
$_gmsg['l_backlog'] = '积压长度';
$_gmsg['l_banperiod'] = '屏蔽时长（秒）';
$_gmsg['l_base'] = '基本';
$_gmsg['l_base2'] = '基本 2';
$_gmsg['l_binding'] = '绑定';
$_gmsg['l_binpath'] = '二进制文件路径';
$_gmsg['l_blockbadreq'] = '屏蔽坏请求';
$_gmsg['l_botWhiteList'] = '机器人白名单';
$_gmsg['l_brcompress'] = 'Brotli压缩';
$_gmsg['l_brcompresslevel'] = 'Brotli压缩级别（动态内容）';
$_gmsg['l_brstaticcompresslevel'] = 'Brotli压缩级别（静态文件）';
$_gmsg['l_bubblewrap'] = 'Bubblewrap 容器';
$_gmsg['l_bubblewrapcmd'] = 'Bubblewrap 命令';
$_gmsg['l_byteslog'] = '字节日志';
$_gmsg['l_cacertfile'] = 'CA 证书文件';
$_gmsg['l_cacertpath'] = 'CA 证书路径';
$_gmsg['l_cacheexpiretime'] = '缓存过期时间（秒）';
$_gmsg['l_cachepolicy'] = '缓存策略';
$_gmsg['l_cacheqs'] = '缓存带查询字符串的请求';
$_gmsg['l_cachereqcookie'] = '缓存带Cookie的请求';
$_gmsg['l_cacherespcookie'] = '缓存带Cookie的响应';
$_gmsg['l_cachestaleage'] = '缓存陈旧时间（秒）';
$_gmsg['l_cachestoragesettings'] = '缓存存储设置';
$_gmsg['l_certchain'] = '证书链';
$_gmsg['l_certfile'] = '证书文件';
$_gmsg['l_cgidsock'] = 'CGI守护进程套接字';
$_gmsg['l_cgipriority'] = 'CGI优先级';
$_gmsg['l_cgisettings'] = 'CGI设置';
$_gmsg['l_cgroups'] = '控制组群';
$_gmsg['l_checksymbollink'] = '检查符号链接';
$_gmsg['l_chrootpath'] = 'Chroot路径';
$_gmsg['l_ciphers'] = '加密器';
$_gmsg['l_clientverify'] = '客户端校验';
$_gmsg['l_command'] = '命令';
$_gmsg['l_compressarchive'] = '压缩存档';
$_gmsg['l_compressibletypes'] = '压缩类型';
$_gmsg['l_concurrentReqLimit'] = '并发请求限制';
$_gmsg['l_configfile'] = '配置文件';
$_gmsg['l_congestionctrl'] = '拥塞控制';
$_gmsg['l_connection'] = '连接';
$_gmsg['l_conntimeout'] = '连接超时时长（秒）';
$_gmsg['l_contextlist'] = '资源集列表';
$_gmsg['l_cpuaffinity'] = 'CPU亲缘性';
$_gmsg['l_cpuhardlimit'] = 'CPU硬限制（秒）';
$_gmsg['l_cpusoftlimit'] = 'CPU软限制（秒）';
$_gmsg['l_crlfile'] = '客户端吊销文件';
$_gmsg['l_crlpath'] = ' 客户端吊销路径';
$_gmsg['l_ctxas'] = 'App Server资源集定义';
$_gmsg['l_ctxb'] = '负载均衡器资源集定义';
$_gmsg['l_ctxc'] = 'CGI资源集定义';
$_gmsg['l_ctxf'] = 'FCGI资源集定义';
$_gmsg['l_ctxg'] = '静态资源集定义';
$_gmsg['l_ctxj'] = 'Java WebApp资源集定义';
$_gmsg['l_ctxl'] = 'LiteSpeed SAPI资源集定义';
$_gmsg['l_ctxmd'] = '模块处理器资源集定义';
$_gmsg['l_ctxp'] = '代理资源集定义';
$_gmsg['l_ctxr'] = '重定向资源集定义';
$_gmsg['l_ctxs'] = 'Servlet资源集定义';
$_gmsg['l_custerrpages'] = '自定义错误页面';
$_gmsg['l_dbname'] = 'DB Name';
$_gmsg['l_debuglevel'] = '调试级别';
$_gmsg['l_defaultaction'] = '默认动作';
$_gmsg['l_defaultcharsetcustomized'] = '自定义默认字符集';
$_gmsg['l_defaultmimetype'] = '默认MIME类型';
$_gmsg['l_defaultvhroot'] = '默认虚拟主机根目录';
$_gmsg['l_desturi'] = '目标URI';
$_gmsg['l_dhparam'] = 'DH 参数';
$_gmsg['l_disableinitlogrotation'] = '禁止初始日志回滚';
$_gmsg['l_disablesechtaccess'] = '禁止.htaccess覆盖';
$_gmsg['l_docroot'] = '文档根';
$_gmsg['l_domain'] = '域名';
$_gmsg['l_domains'] = '域名';
$_gmsg['l_dynreqpersec'] = '动态态请求/秒';
$_gmsg['l_enablebrcompress'] = '启用Brotli压缩';
$_gmsg['l_enablecache'] = '启用缓存';
$_gmsg['l_enablecensorship'] = '启用请求过滤';
$_gmsg['l_enablechroot'] = '启用Chroot环境';
$_gmsg['l_enablecompress'] = '启用压缩';
$_gmsg['l_enablecoredump'] = '启用核心转储';
$_gmsg['l_enabled'] = '已启用';
$_gmsg['l_enabledhe'] = '启用DH密钥交换';
$_gmsg['l_enabledyngzipcompress'] = '启用动态压缩';
$_gmsg['l_enableecdhe'] = '启用ECDH密钥交换';
$_gmsg['l_enableexpires'] = '启用过期';
$_gmsg['l_enablegzip'] = '启用GZIP压缩';
$_gmsg['l_enableh2c'] = '在明文传输上启用HTTP/2';
$_gmsg['l_enablehooks'] = '启用钩子(Hook)';
$_gmsg['l_enablehotlinkctrl'] = '启用盗链防护';
$_gmsg['l_enableipgeo'] = '启用IP地理定位';
$_gmsg['l_enablelve'] = 'Cloud Linux';
$_gmsg['l_enableprivatecache'] = '启用私有缓存';
$_gmsg['l_enablequic'] = '启用HTTP3/QUIC';
$_gmsg['l_enablerailshosting'] = '启用共享主机';
$_gmsg['l_enablerewrite'] = '启用重写';
$_gmsg['l_enablescript'] = '启用脚本/外部应用程序';
$_gmsg['l_enablestapling'] = '启用OCSP Stapling';
$_gmsg['l_enablestderrlog'] = '启用标准错误日志（stderr）';
$_gmsg['l_env'] = '环境变量';
$_gmsg['l_envvariable'] = '环境变量';
$_gmsg['l_errcode'] = '错误代码';
$_gmsg['l_expires'] = '过期设置';
$_gmsg['l_expiresByType'] = '按类型过期';
$_gmsg['l_expiresdefault'] = '默认过期';
$_gmsg['l_extappabort'] = '外部应用程序放弃';
$_gmsg['l_extappchrootmode'] = '外部应用程序Chroot模式';
$_gmsg['l_extappchrootpath'] = '外部应用程序Chroot路径';
$_gmsg['l_extappresctl'] = '外部应用程序资源控制';
$_gmsg['l_extapps'] = '外部应用程序';
$_gmsg['l_extappsec'] = 'External App Security';
$_gmsg['l_externalredirect'] = '外部重定向';
$_gmsg['l_extfcgiauth'] = 'FastCGI认证器';
$_gmsg['l_extlb'] = '负载均衡器';
$_gmsg['l_extlogger'] = '管道日志器';
$_gmsg['l_extlsapi'] = 'LiteSpeed SAPI应用程序';
$_gmsg['l_extproxy'] = '网络服务器';
$_gmsg['l_extraHeaders'] = '头部操作';
$_gmsg['l_extservlet'] = 'Servlet引擎';
$_gmsg['l_fcgiapp'] = 'FastCGI应用程序';
$_gmsg['l_fileaccess'] = '文件访问';
$_gmsg['l_fileaccesscontrol'] = '文件访问控制';
$_gmsg['l_fileetag'] = '文件ETag';
$_gmsg['l_filename'] = '文件路径';
$_gmsg['l_followsymbollink'] = '跟随符号链接';
$_gmsg['l_forcegid'] = '强制GID';
$_gmsg['l_forcemimetype'] = '强制MIME类型';
$_gmsg['l_forcestrictownership'] = '强制严格属主检查';
$_gmsg['l_generalsettings'] = '常规设置';
$_gmsg['l_geoipdb'] = 'MaxMind地理定位数据库';
$_gmsg['l_geoipdbfile'] = '数据库文件路径';
$_gmsg['l_gracefulrestarttimeout'] = '平滑重启超时时间（秒）';
$_gmsg['l_graceperiod'] = '宽限期（秒）';
$_gmsg['l_groupdbattrgroupmember'] = '组成员属性名';
$_gmsg['l_groupdbcachetimeout'] = '组数据库缓存超时时间（秒）';
$_gmsg['l_groupdbentries'] = '组数据库条目';
$_gmsg['l_groupdbentry'] = '组数据库条目';
$_gmsg['l_groupdblocation'] = '组数据库地址';
$_gmsg['l_groupdbmaxcachesize'] = '组数据库最大缓存大小';
$_gmsg['l_groupname'] = '组名';
$_gmsg['l_groups'] = '组定义';
$_gmsg['l_gzip'] = 'Gzip压缩';
$_gmsg['l_gzipautoupdatestatic'] = '自动更新静态文件';
$_gmsg['l_gzipbr'] = 'GZIP/Brotli压缩';
$_gmsg['l_gzipcachedir'] = '静态GZIP缓存目录';
$_gmsg['l_gzipcompresslevel'] = '压缩级别（动态内容）';
$_gmsg['l_gzipmaxfilesize'] = '静态文件最大尺寸（字节）';
$_gmsg['l_gzipminfilesize'] = '静态文件最小尺寸（字节）';
$_gmsg['l_gzipstaticcompresslevel'] = 'GZIP压缩级别（静态文件）';
$_gmsg['l_handlername'] = '处理器名称';
$_gmsg['l_handlertype'] = '处理器类型';
$_gmsg['l_hardlimit'] = '连接数硬限制';
$_gmsg['l_hidesiginerrorpage'] = '隐藏错误页签名';
$_gmsg['l_hook'] = '钩子';
$_gmsg['l_hotlinkprotection'] = '防盗链';
$_gmsg['l_ignorereqcachectrl'] = '忽略请求中的缓存控制';
$_gmsg['l_ignorerespcachectrl'] = '忽略响应中的缓存控制';
$_gmsg['l_inbandwidth'] = '入口带宽（字节/秒）';
$_gmsg['l_indexfiles'] = '索引文件';
$_gmsg['l_inittimeout'] = '初始请求超时时间（秒）';
$_gmsg['l_inmembufsize'] = '内存读写缓冲区大小';
$_gmsg['l_instances'] = '实例';
$_gmsg['l_internal'] = '是内置模块';
$_gmsg['l_ip'] = 'IP地址';
$_gmsg['l_ip2locDB'] = 'IP2Location数据库';
$_gmsg['l_ip2locDBCache'] = 'DB Cache Type';
$_gmsg['l_ip2locDBFile'] = 'IP2Location数据库文件路径';
$_gmsg['l_keepalivetimeout'] = '持久连接超时时间（秒）';
$_gmsg['l_keepdays'] = '保留天数';
$_gmsg['l_keyfile'] = '私钥文件';
$_gmsg['l_ldapbinddn'] = 'LDAP绑定DN';
$_gmsg['l_ldapbindpasswd'] = 'LDAP绑定密码';
$_gmsg['l_ldaprealmdef'] = 'LDAP领域定义';
$_gmsg['l_listenerlist'] = '监听器列表';
$_gmsg['l_listenername'] = '监听器名称';
$_gmsg['l_loadapacheconf'] = '载入Apache配置';
$_gmsg['l_loadbalancer'] = '负载均衡器';
$_gmsg['l_location'] = '位置';
$_gmsg['l_logcontrol'] = '日志管理';
$_gmsg['l_logformat'] = '日志格式';
$_gmsg['l_loggeraddress'] = '远程日志器地址（可选）';
$_gmsg['l_logheaders'] = '记录头部';
$_gmsg['l_loglevel'] = '日志级别';
$_gmsg['l_lsapiapp'] = 'LSAPI应用程序';
$_gmsg['l_lsrecaptcha'] = 'LS reCAPTCHA';
$_gmsg['l_mappedlisteners'] = '映射的监听器';
$_gmsg['l_matchedhosts'] = '正则表达式匹配域名';
$_gmsg['l_maxCGIInstances'] = '最大CGI实例数量';
$_gmsg['l_maxTries'] = '最大尝试次数';
$_gmsg['l_maxcachedfilesize'] = '缓存的小型文件最大大小（字节）';
$_gmsg['l_maxconns'] = '最大连接数';
$_gmsg['l_maxdynrespheadersize'] = '动态回应报头最大大小（字节）';
$_gmsg['l_maxdynrespsize'] = '动态回应主内容最大大小（字节）';
$_gmsg['l_maxidletime'] = '最长闲置时间';
$_gmsg['l_maxkeepalivereq'] = '最大持续连接请求数';
$_gmsg['l_maxmmapfilesize'] = '最大MMAP文件大小（字节）';
$_gmsg['l_maxobjsize'] = '最大对象大小';
$_gmsg['l_maxreqbodysize'] = '最大请求主内容大小（字节）';
$_gmsg['l_maxreqheadersize'] = '最大请求头大小（字节）';
$_gmsg['l_maxrequrllen'] = '最大请求URL长度（字节）';
$_gmsg['l_maxsslconns'] = '最大SSL连接数';
$_gmsg['l_membervhosts'] = '虚拟主机成员';
$_gmsg['l_membervhroot'] = '虚拟主机成员根目录';
$_gmsg['l_membervhroot_note'] = '可选项：你可以在此设置一个与缺省值不同的虚拟主机根目录（VH_ROOT）';
$_gmsg['l_memhardlimit'] = '内存硬限制（字节）';
$_gmsg['l_memsoftlimit'] = '内存软限制（字节）';
$_gmsg['l_mimesettings'] = 'MIME设置';
$_gmsg['l_mimetype'] = 'MIME类型';
$_gmsg['l_mimetypedef'] = 'MIME类型定义';
$_gmsg['l_mimetypeentry'] = 'MIME类型条目';
$_gmsg['l_mingid'] = '最小的GID';
$_gmsg['l_minuid'] = '最小的UID';
$_gmsg['l_module'] = '模块';
$_gmsg['l_moduleconf'] = '模块设置';
$_gmsg['l_modulehandler'] = '模块处理器';
$_gmsg['l_moduleparams'] = '模块参数';
$_gmsg['l_name'] = '名称';
$_gmsg['l_newadminuser'] = '创建网络管理员用户';
$_gmsg['l_newcontext'] = '添加资源集';
$_gmsg['l_newextapp'] = '添加外部应用程序';
$_gmsg['l_newpass'] = '新密码';
$_gmsg['l_newrealm'] = '创建领域';
$_gmsg['l_nocachedomain'] = '不缓存的域名';
$_gmsg['l_nocacheurl'] = '不缓存的网址';
$_gmsg['l_nodebin'] = 'Node路径';
$_gmsg['l_nodesettings'] = 'Node.js App默认设置';
$_gmsg['l_notes'] = '备注';
$_gmsg['l_numworkers'] = '工作器数量';
$_gmsg['l_ocspcacerts'] = 'OCSP CA证书';
$_gmsg['l_ocsprespmaxage'] = 'OCSP响应最大时长（秒）';
$_gmsg['l_ocspresponder'] = 'OCSP响应器';
$_gmsg['l_ocspstapling'] = '附加在线证书状态协议(OCSP Stapling)';
$_gmsg['l_oldpass'] = '旧密码';
$_gmsg['l_onlyself'] = '仅限自我跳转';
$_gmsg['l_order'] = '顺序';
$_gmsg['l_outbandwidth'] = '出口带宽（字节/秒）';
$_gmsg['l_pass'] = '密码';
$_gmsg['l_passfilerealmdef'] = '密码文件领域定义';
$_gmsg['l_path'] = '路径';
$_gmsg['l_pckeepalivetimeout'] = '持续连接超时时长';
$_gmsg['l_perclientthrottle'] = '单客户调节';
$_gmsg['l_persistconn'] = '持久连接';
$_gmsg['l_phpinioverride'] = 'php.ini 覆盖';
$_gmsg['l_phpsuexec'] = 'PHP suEXEC';
$_gmsg['l_phpsuexecmaxconn'] = 'PHP suEXEC最大连接数';
$_gmsg['l_pipedlogger'] = '管道日志器';
$_gmsg['l_port'] = '端口';
$_gmsg['l_priority'] = '优先级';
$_gmsg['l_privatecacheexpiretime'] = '私有缓存过期时间（秒）';
$_gmsg['l_process'] = '进程';
$_gmsg['l_prochardlimit'] = '进程硬限制';
$_gmsg['l_procsoftlimit'] = '进程软限制';
$_gmsg['l_protocolver'] = '协议版本';
$_gmsg['l_quic'] = 'HTTP3/QUIC';
$_gmsg['l_quiccfcw'] = '连接流量控制窗口';
$_gmsg['l_quichandshaketimeout'] = '握手超时时间（秒）';
$_gmsg['l_quicidletimeout'] = '空闲超时时间（秒）';
$_gmsg['l_quicmaxcfcw'] = '最大连接流量窗口值设置';
$_gmsg['l_quicmaxsfcw'] = '最大流量窗口值设置';
$_gmsg['l_quicmaxstreams'] = '每个连接的最大并发数';
$_gmsg['l_quicsfcw'] = '连接流量窗口值';
$_gmsg['l_quicshmdir'] = 'QUIC SHM 目录';
$_gmsg['l_quicversions'] = 'HTTP3/QUIC 版本';
$_gmsg['l_railsapplimit'] = '单账号最大应用程序数量';
$_gmsg['l_railshosting'] = 'Rack/Rails共享主机';
$_gmsg['l_railssettings'] = 'App Server设置';
$_gmsg['l_ramdiskpath'] = '内存磁盘路径';
$_gmsg['l_rcvbufsize'] = '接收缓冲区大小';
$_gmsg['l_realm'] = '领域';
$_gmsg['l_realmlist'] = '认证领域列表';
$_gmsg['l_realmname'] = '领域名称';
$_gmsg['l_realmtype'] = '数据库类型';
$_gmsg['l_recapenabled'] = '启用reCAPTCHA';
$_gmsg['l_recaptype'] = 'reCAPTCHA类型';
$_gmsg['l_redirecturi'] = '重定向URL';
$_gmsg['l_regConnLimit'] = '连接限制';
$_gmsg['l_renegprotection'] = 'SSL重新协商保护';
$_gmsg['l_reqresp'] = '请求/响应调整';
$_gmsg['l_requestfilterruleset'] = '请求过滤规则集';
$_gmsg['l_requiredauthuser'] = '要求（已认证的用户/组）';
$_gmsg['l_requiredpermissionmask'] = '必需的权限掩码';
$_gmsg['l_respbuffer'] = '响应缓冲';
$_gmsg['l_restrained'] = '访问管制';
$_gmsg['l_restricteddirpermissionmask'] = '脚本目录限制权限掩码';
$_gmsg['l_restrictedpermissionmask'] = '限制权限掩码';
$_gmsg['l_restrictedscriptpermissionmask'] = '脚本限制权限掩码';
$_gmsg['l_retrytimeout'] = '重试超时时间（秒）';
$_gmsg['l_retypepass'] = '确认新密码';
$_gmsg['l_reuseport'] = '启用REUSEPORT';
$_gmsg['l_rewritebase'] = '重写基准';
$_gmsg['l_rewritecontrol'] = '重写控制';
$_gmsg['l_rewritedocrootrules'] = '文档根目录重写规则';
$_gmsg['l_rewriteinherit'] = '重写继承';
$_gmsg['l_rewritemap'] = '重写映射';
$_gmsg['l_rewriterules'] = '重写规则';
$_gmsg['l_rollingsize'] = '回滚大小（字节）';
$_gmsg['l_rubybin'] = 'Ruby路径';
$_gmsg['l_rubyproclimit'] = '每个的用户最大Ruby进程数';
$_gmsg['l_ruleset'] = '规则定义';
$_gmsg['l_runningas'] = '以此身份运行';
$_gmsg['l_runonstartup'] = '启动时运行';
$_gmsg['l_runtimemode'] = '运行模式';
$_gmsg['l_scanpost'] = '扫描请求主内容';
$_gmsg['l_secauditlog'] = '安全审计日志';
$_gmsg['l_secauditlogengine'] = '启用安全审计日志';
$_gmsg['l_secretKey'] = 'Secret Key';
$_gmsg['l_secure'] = '加密连接';
$_gmsg['l_securedconn'] = '加密连接';
$_gmsg['l_securityandfeatures'] = '安全和特性';
$_gmsg['l_serverlog'] = '服务器日志';
$_gmsg['l_servermoduledef'] = '服务器模块定义';
$_gmsg['l_servermodulesdef'] = '服务器模块定义';
$_gmsg['l_servername'] = '服务器名称';
$_gmsg['l_serverprocess'] = '服务器进程';
$_gmsg['l_serversig'] = '服务器签名';
$_gmsg['l_servletengine'] = 'Servlet引擎';
$_gmsg['l_sessiontimeout'] = '会话超时时间（秒）';
$_gmsg['l_setuidmode'] = '外部应用程序设置UID模式';
$_gmsg['l_shdef'] = '脚本处理器定义';
$_gmsg['l_shmDefaultDir'] = '默认SHM目录';
$_gmsg['l_sitealiases'] = '网站别名';
$_gmsg['l_sitedomain'] = '网站域名';
$_gmsg['l_sitekey'] = 'Site Key';
$_gmsg['l_smartkeepalive'] = '智能持续连接';
$_gmsg['l_sndbufsize'] = '发送缓冲区大小（字节）';
$_gmsg['l_softlimit'] = '连接软限制';
$_gmsg['l_spdyadheader'] = 'SPDY公告';
$_gmsg['l_ssl'] = 'SSL私钥和证书';
$_gmsg['l_sslConnLimit'] = 'SSL连接限制';
$_gmsg['l_sslEnableMultiCerts'] = '启用多SSL证书';
$_gmsg['l_sslSessionCache'] = '启用会话缓存';
$_gmsg['l_sslSessionCacheSize'] = '会话缓存大小(字节)';
$_gmsg['l_sslSessionCacheTimeout'] = '会话缓存超时(秒)';
$_gmsg['l_sslSessionTicketKeyFile'] = 'SSL会话记录单Key文件路径';
$_gmsg['l_sslSessionTicketLifetime'] = 'SSL会话记录单生命周期(秒)';
$_gmsg['l_sslSessionTickets'] = '启用会话单';
$_gmsg['l_sslStrongDhKey'] = '强SSL DH密钥';
$_gmsg['l_sslprotocol'] = 'SSL协议';
$_gmsg['l_startupfile'] = '启动文件';
$_gmsg['l_statDir'] = '状态统计输出目录';
$_gmsg['l_staticcompresslevel'] = '压缩级别（静态内容）';
$_gmsg['l_staticreqpersec'] = '静态请求数/秒';
$_gmsg['l_statuscode'] = '状态码';
$_gmsg['l_storagepath'] = '存储路径';
$_gmsg['l_suexecgrp'] = '以此用户组身份运行';
$_gmsg['l_suexecgrp1'] = 'suEXEC Group';
$_gmsg['l_suexecuser'] = '以此用户身份运行';
$_gmsg['l_suexecuser1'] = 'suEXEC User';
$_gmsg['l_suffix'] = '后缀';
$_gmsg['l_suspendvh'] = '冻结虚拟主机';
$_gmsg['l_swappingdir'] = '交换目录';
$_gmsg['l_templatefile'] = '模板文件';
$_gmsg['l_totalinmemcachesize'] = '小文件缓存总大小（字节）';
$_gmsg['l_totalmmapcachesize'] = '总MMAP缓存大小（字节）';
$_gmsg['l_tplist'] = '虚拟主机模板列表';
$_gmsg['l_tpname'] = '模板名称';
$_gmsg['l_tuningos'] = '操作系统优化';
$_gmsg['l_tuningsslsettings'] = 'SSL全局设定';
$_gmsg['l_tuningstatic'] = '静态文件传输优化';
$_gmsg['l_type'] = '类型';
$_gmsg['l_umask'] = '权限掩码';
$_gmsg['l_updateinterval'] = '更新间隔';
$_gmsg['l_updatemode'] = '更新模式';
$_gmsg['l_updateoffsetsecs'] = '更新偏移时间（秒）';
$_gmsg['l_uploadfile'] = '文件上传';
$_gmsg['l_uploadpassbypath'] = '通过文件路径传递数据';
$_gmsg['l_uploadtmpdir'] = '临时文件路径';
$_gmsg['l_uploadtmpfilepermission'] = '临时文件权限';
$_gmsg['l_uri'] = 'URI';
$_gmsg['l_url'] = 'URL';
$_gmsg['l_urlfilter'] = '资源集';
$_gmsg['l_useServer'] = '使用服务器日志';
$_gmsg['l_useaio'] = '使用异步磁盘读写(AIO)';
$_gmsg['l_useapacheconf'] = '使用Apache配置文件';
$_gmsg['l_useipinproxyheader'] = '使用报头中的客户端IP';
$_gmsg['l_userdbattrmemberof'] = 'Member-of属性';
$_gmsg['l_userdbattrpasswd'] = '密码属性';
$_gmsg['l_userdbcachetimeout'] = '用户数据库缓存超时时间（秒）';
$_gmsg['l_userdbentries'] = '用户数据库条目';
$_gmsg['l_userdbentry'] = '用户数据库条目';
$_gmsg['l_userdblocation'] = '用户数据库地址';
$_gmsg['l_userdbmaxcachesize'] = '用户数据库最大缓存大小';
$_gmsg['l_username'] = '用户名';
$_gmsg['l_users'] = '用户';
$_gmsg['l_usesendfile'] = '使用sendfile()';
$_gmsg['l_useserverindexfiles'] = '使用服务器索引文件';
$_gmsg['l_verifydepth'] = '检查深度';
$_gmsg['l_vhaliases'] = '别名';
$_gmsg['l_vhlog'] = '虚拟主机日志';
$_gmsg['l_vhmappings'] = '虚拟主机映射';
$_gmsg['l_vhname'] = '虚拟主机名';
$_gmsg['l_vhost'] = '虚拟主机';
$_gmsg['l_vhostlist'] = '虚拟主机列表';
$_gmsg['l_vhroot'] = '虚拟主机根目录';
$_gmsg['l_vhtemplate'] = '虚拟主机模板';
$_gmsg['l_webserver'] = '网络服务器';
$_gmsg['l_websocketdef'] = '网络套接字定义';
$_gmsg['l_websocketsetup'] = '网络套接字代理设置';
$_gmsg['l_workers'] = '工作器';
$_gmsg['l_workingdir'] = '工作路径';
$_gmsg['l_wsgibin'] = 'WSGI 路径';
$_gmsg['l_wsgisettings'] = 'Python WSGI默认设置';


$_gmsg['o_cagefswithoutsuexec'] = '不包含suEXEC的CageFS';
$_gmsg['o_checkbox'] = 'Checkbox';
$_gmsg['o_custchrootpath'] = '自定义的Chroot路径';
$_gmsg['o_daily'] = '每日';
$_gmsg['o_deprecated'] = '废弃';
$_gmsg['o_disabled'] = '禁用';
$_gmsg['o_enableabortforallreq'] = '开启中断所有请求';
$_gmsg['o_enableabortforreqfromexternalip'] = '开启中断外部IP访问请求。';
$_gmsg['o_hidefullheader'] = '隐藏全部头';
$_gmsg['o_hidever'] = '隐藏版本';
$_gmsg['o_high'] = '高';
$_gmsg['o_hourly'] = '每小时';
$_gmsg['o_ifownermatch'] = '仅限相同属主';
$_gmsg['o_invisible'] = 'Invisible';
$_gmsg['o_keepfilemapped'] = '保持文件映射（64位系统）';
$_gmsg['o_keepheaderfortrusted'] = '在可信IP中保留头';
$_gmsg['o_low'] = '低';
$_gmsg['o_medium'] = '中';
$_gmsg['o_modifiedtime'] = '修改时间';
$_gmsg['o_monthly'] = '每月';
$_gmsg['o_no'] = '否';
$_gmsg['o_noabort'] = '不终止';
$_gmsg['o_nofornph'] = '对不可解析的头(NPH)为否';
$_gmsg['o_none'] = '无';
$_gmsg['o_notset'] = '未设置';
$_gmsg['o_off'] = '关';
$_gmsg['o_on'] = '开';
$_gmsg['o_overridecpanelrestartscript'] = '替代cPanel重启HTTPD的脚本';
$_gmsg['o_ownlogfile'] = '自有日志文件';
$_gmsg['o_sameasserver'] = '与服务器相同';
$_gmsg['o_serverslogfile'] = '服务器的日志文件';
$_gmsg['o_showver'] = '显示版本';
$_gmsg['o_size'] = '大小';
$_gmsg['o_thrucgidaemon'] = '通过CGI守护进程';
$_gmsg['o_trustediponly'] = '仅限受信任的IP';
$_gmsg['o_use_last_ip_for elb'] = '使用最后一个IP（对于AWS ELB）';
$_gmsg['o_useapachebinwrapper'] = '使用apache运行替身';
$_gmsg['o_userhomedironly'] = '只有用户主目录';
$_gmsg['o_vhroot'] = '虚拟主机根目录';
$_gmsg['o_weekly'] = '每周';
$_gmsg['o_yes'] = '是';
$_gmsg['o_yesdaemonmode'] = 'Yes (Daemon Mode)';
$_gmsg['o_yesdetachmode'] = '是（独立模式）';


$_gmsg['parse_awstatsuri'] = '以 / 开头并且以 / 结尾';
$_gmsg['parse_compressibletypes'] = '(!)MIME类型, 如 */*, text/*, text/html, text/*, !text/css';
$_gmsg['parse_defaultmimetype'] = 'MIME类型, 如 text/html';
$_gmsg['parse_env'] = 'PROPERTY=VALUE';
$_gmsg['parse_expiresByType'] = 'MIME类型=A|Mseconds, MIME可以是 */*, text/*, text/html';
$_gmsg['parse_expiresdefault'] = '[A|M]###, A 代表用户登入时间, M 代表文件修改时间, ### 为秒数';
$_gmsg['parse_forcemimetype'] = 'MIME类型如text/html,或输入 \\\"NONE\\\" 来禁止强制继承的类型。';
$_gmsg['parse_geodbenv'] = 'Variable_Name mapped_DB_data';
$_gmsg['parse_mimetype'] = '如 text/html';
$_gmsg['parse_recaptchakey'] = 'key string assigned from your google reCAPTCHA account';
$_gmsg['parse_rewritemaplocation'] = 'txt:/location 或者 rnd:/location 或者 int:(toupper|tolower|escape|unescape)';
$_gmsg['parse_secpermissionmask'] = '3位以上的八进制数，默认限制权限掩码为 000';
$_gmsg['parse_spdyadheader'] = '格式要求: ssl_port:npn-spdy/version 如 443:npn-spdy/3';
$_gmsg['parse_suffix'] = '逗号隔开的列表，允许字符[A-z0-9_\\-]';
$_gmsg['parse_tpfile'] = '需要变量$VH_NAME 或 $VH_ROOT';
$_gmsg['parse_tpname'] = '需要变量$VH_NAME';
$_gmsg['parse_tpvhconffile'] = '需要变量 $VH_NAME 并以 .conf结尾。建议位置为 $SERVER_ROOT/conf/vhosts/$VH_NAME/vhconf.conf';
$_gmsg['parse_umask'] = '[000-777]';
$_gmsg['parse_uploadtmpfilepermission'] = '3 digits octet number, Default value is 666';
$_gmsg['parse_userdblocation'] = '以ldap:// 或 ldaps://开头';


$_gmsg['service_active'] = '运行中';
$_gmsg['service_addtomonitor'] = '加入监控';
$_gmsg['service_at'] = '在';
$_gmsg['service_availconn'] = '未用的连接数';
$_gmsg['service_availssl'] = '未用的SSL连接数';
$_gmsg['service_blockedipcnt'] = 'DDoS防护屏蔽的IP数';
$_gmsg['service_bpsin'] = 'Http 入口带宽(KB)';
$_gmsg['service_bpsout'] = 'Http 出口带宽(KB)';
$_gmsg['service_confirmmonitor'] = '确定要监控吗';
$_gmsg['service_debuglogstatus'] = '调试日志';
$_gmsg['service_disabled'] = '停用';
$_gmsg['service_displevel'] = '显示级别';
$_gmsg['service_eapcount'] = '外部应用程序计数';
$_gmsg['service_eapidle'] = '闲置的外部应用程序进程';
$_gmsg['service_eapinuse'] = '在使用的外部应用程序进程';
$_gmsg['service_eapreqpersec'] = '外部应用程序进程请求数/秒';
$_gmsg['service_eapwaitq'] = '外部应用程序进程等待队列';
$_gmsg['service_effmax'] = '实际的最大值';
$_gmsg['service_enablevh'] = '启用这个虚拟机';
$_gmsg['service_enterpass'] = '请输入密码';
$_gmsg['service_enteruser'] = '请输入用户名';
$_gmsg['service_error'] = '错误';
$_gmsg['service_filterbyvn'] = '按照虚拟主机名称筛选';
$_gmsg['service_gotologviewer'] = '查看日志检视器';
$_gmsg['service_higheston'] = '最高值出现在';
$_gmsg['service_idle'] = '闲置';
$_gmsg['service_idleconn'] = '闲置连接数';
$_gmsg['service_intemplate'] = '位于模板';
$_gmsg['service_inuse'] = '正在使用';
$_gmsg['service_ismonitored'] = '已被监控';
$_gmsg['service_length'] = '长度';
$_gmsg['service_level'] = '级别';
$_gmsg['service_livefeeds'] = '实时消息源';
$_gmsg['service_loglastsize'] = '最后 %%size%%';
$_gmsg['service_logresnote'] = '搜索了%%totallines%%条日志并且找到%%outlines%%条高于%%level%%级别';
$_gmsg['service_maxconn'] = '最大连接数';
$_gmsg['service_maxsslconn'] = '最大SSL连接数';
$_gmsg['service_mesg'] = '消息';
$_gmsg['service_minutes'] = '分钟';
$_gmsg['service_monitormaxallowed'] = '你只能最多监控';
$_gmsg['service_nameallowexp'] = '名称允许包含正则表达式';
$_gmsg['service_notrunning'] = '没有在运行';
$_gmsg['service_plainconn'] = '使用的连接数';
$_gmsg['service_pool'] = '池';
$_gmsg['service_realtime'] = '实时';
$_gmsg['service_refreshinterval'] = '刷新间隔';
$_gmsg['service_reqpersec'] = '请求数/秒';
$_gmsg['service_reqprocessing'] = '正在处理的请求';
$_gmsg['service_requesting'] = '请求中';
$_gmsg['service_restartconfirm'] = '你确定要重启LiteSpeed吗？';
$_gmsg['service_resumevhconfirm'] = '你确定要重新激活这个虚拟主机吗？';
$_gmsg['service_retrieve'] = '取回';
$_gmsg['service_running'] = '运行中';
$_gmsg['service_scope'] = '范围';
$_gmsg['service_searchfrom'] = '搜索从';
$_gmsg['service_seconds'] = '秒';
$_gmsg['service_server'] = '服务器';
$_gmsg['service_servererrlog'] = '服务器错误日志';
$_gmsg['service_size'] = '大小';
$_gmsg['service_sslbpsin'] = 'Https 入口带宽(KB)';
$_gmsg['service_sslbpsout'] = 'Https 出口带宽(KB)';
$_gmsg['service_sslconn'] = '使用的SSL连接数';
$_gmsg['service_stop'] = '停止';
$_gmsg['service_stopped'] = '停止的';
$_gmsg['service_suspendvh'] = '冻结这个虚拟主机';
$_gmsg['service_suspendvhconfirm'] = '你确定要冻结这个虚拟主机吗?';
$_gmsg['service_time'] = '时间';
$_gmsg['service_toggledebug'] = '确定要切换调试日志?';
$_gmsg['service_toggledebuglog'] = '切换调试日志';
$_gmsg['service_toggledebugmsg'] = '当调试日志开启时，硬盘可能会被填满。只在调试时短时间开启。';
$_gmsg['service_totalreq'] = '总请求数';
$_gmsg['service_uptime'] = 'LSWS运行时间';
$_gmsg['service_waitq'] = '等待队列';
$_gmsg['service_was'] = '为';
$_gmsg['service_willrefresh'] = '该页面将在几秒钟后刷新...';


$_gmsg['buildphp_addonmodules'] = '附加模块';
$_gmsg['buildphp_binarylocnote'] = '如果编译执行成功，PHP二进制将在%%server_root%%fcgi-bin/下以
		%%binname%%为名创建，并且符号链接lsphp%%phpver%%会被创建或更新为最新编译的PHP二进制。
		如果%%binname%%已经存在，他将被重命名为%%binname%%.bak。';
$_gmsg['buildphp_compilerflags'] = '编译器标志';
$_gmsg['buildphp_confparam'] = '配置参数';
$_gmsg['buildphp_confsaved'] = '配置保存成功。你可以在下一次编译时使用。';
$_gmsg['buildphp_detaillog'] = '详细日志 ';
$_gmsg['buildphp_eaccelerator'] = '(操作码缓存) 只支持PHP 5.2 ~ 5.4';
$_gmsg['buildphp_enableextnote'] = '如要开启扩展，请确认以下内容已添加至php.ini配置文件中。
									另外，你需要检查日志详细信息来确认扩展安装的目录并且将该目录路径添加至你的php.ini配置文件中。';
$_gmsg['buildphp_errchmod'] = 'chmod失败';
$_gmsg['buildphp_errcreatescript'] = '创建脚本失败';
$_gmsg['buildphp_errinprogress'] = '当前批处理正在运行。';
$_gmsg['buildphp_errnobash'] = '这个编译工具需要安装bash（命令：pkg_add -r bash）。请在进行下一步前确认bash可用。';
$_gmsg['buildphp_errquotes'] = '请使用单引号来替代双引号';
$_gmsg['buildphp_extrapathenv'] = '额外环境变量';
$_gmsg['buildphp_failgenscript'] = '创建编译脚本失败，请先尝试手动修复错误。';
$_gmsg['buildphp_failsaveconf'] = '保存现配置文件失败';
$_gmsg['buildphp_finishsuccess'] = '成功完成';
$_gmsg['buildphp_installpathprefix'] = '安装路径前缀';
$_gmsg['buildphp_loadconf'] = '载入配置';
$_gmsg['buildphp_mailheader1'] = 'PHP邮件头补丁';
$_gmsg['buildphp_mailheader2'] = '确认邮件源';
$_gmsg['buildphp_mainstatus'] = '主状态';
$_gmsg['buildphp_manualrunnotice'] = '<p>出于安全原因，请登入您的服务器并从shell运行预设置的脚本。你可以通过这个界面监控脚本运行。</p>
	<p>如果编译成功，请根据需求更新php.ini。为了让更新生效，请进行一次平滑重启。</p>
	<p>如果由于错误停止，可能是由于丢失了安装包，当你安装完丢失的安装包，重新运行相同命令，该页面将会显示更新后的日志。更多详情，请查看<a href="https://www.litespeedtech.com/support/wiki/doku.php/litespeed_wiki:php" rel="noopener noreferrer" target="_blank">LiteSpeed wiki</a></p>
	<p>如果你以root身份登入，你可以直接运行命令：<br><code>%%manual_script%%</code></p>
	<p>如果你是以具有sudo权限的用户登入，你可以通过sudo运行命令并输入root密码：
	<code>sudo %%manual_script%%</code></p>';
$_gmsg['buildphp_nobrowserrefresh'] = '请不要在PHP编译过程中使用浏览器刷新，后退及前进功能。';
$_gmsg['buildphp_opcodecache'] = '操作码缓存';
$_gmsg['buildphp_phpver'] = 'PHP版本';
$_gmsg['buildphp_restoredefault'] = '恢复默认设置';
$_gmsg['buildphp_step1'] = '选择PHP版本';
$_gmsg['buildphp_step2'] = '选择编译选项';
$_gmsg['buildphp_step3'] = '下载源代码';
$_gmsg['buildphp_step4'] = '编译并监控';
$_gmsg['buildphp_stopduetoerr'] = '由于错误停止。请检查日志并手动修复。';
$_gmsg['buildphp_suhosin'] = '(General Hardening) 只支持PHP5.4和5.5版本';
$_gmsg['buildphp_updatever'] = '如果你使用下列列表以外的版本，你需要手动更改设置文件';
$_gmsg['buildphp_useprevconf'] = '使用上一次编译的配置文件';


$_gmsg['mail_failedlogin'] = 'LiteSpeed管理员控制台登陆失败';
$_gmsg['mail_failedlogin_c'] = '近期发生了一次失败的LiteSpeed登陆。失败登陆信息如下
	日期/时间: %%date%%
	用户名: %%authUser%%
	IP 地址: %%ip%%
	URL: %%url%%
如果你并不熟悉该IP地址，请按照下列建议来保护管理员控制台：
1. 请在管理员控制台设置中设置允许访问列表，限制特定的IP访问;
2. 更改默认7080监听端口;
3. 不要使用简单密码;
4. 使用https登陆管理员控制台。';


